@@ -75,8 +75,8 @@ sub run {
             $logger->debug2("Waiting in mainloop");
             foreach my $target (@targets) {
                 my $date = $target->getFormatedNextRunDate();
-                my $type = $target->getType();
-                my $name = $target->getName();
+                my $type = $target->_getType();
+                my $name = $target->_getName();
                 $logger->debug2("$type target next run: $date - $name");
             }
         } else {
@@ -114,7 +114,7 @@ sub run {
 
             if ($logger && $config->{'no-fork'}) {
                 my $date = $target->getFormatedNextRunDate();
-                my $type = $target->getType();
+                my $type = $target->_getType();
                 $logger->debug2("$type target scheduled: $date");
             }
 
@@ -279,9 +279,6 @@ sub createDaemon {
     } elsif (my $pid = $daemon->Init()) {
         $logger->debug("$PROVIDER Agent daemonized with PID $pid") if $logger;
         exit 0;
-    } else {
-        # Reload the logger in forked process to avoid some related issues
-        $logger->reload();
     }
 
     # From here we can enable our pidfile deletion on terminate
@@ -343,8 +340,7 @@ sub ApplyServiceOptimizations {
     my ($self) = @_;
 
     # Preload all IDS databases to avoid reload them all the time during inventory
-    my @planned = map { $_->plannedTasks() } $self->getTargets();
-    if (grep { /^inventory$/i } @planned) {
+    if (grep { /^inventory$/i } @{$self->{tasksExecutionPlan}}) {
         my %datadir = ( datadir => $self->{datadir} );
         getPCIDeviceVendor(%datadir);
         getUSBDeviceVendor(%datadir);
