@@ -41,7 +41,7 @@ sub setTrustedAddresses {
 
     # compute addresses allowed for push requests
     foreach my $target ($self->{agent}->getTargets()) {
-        next unless $target->isType('server');
+        next unless $target->isa('FusionInventory::Agent::Target::Server');
         my $url  = $target->getUrl();
         my $host = URI->new($url)->host();
         my @addresses = compile($host, $self->{logger});
@@ -145,12 +145,12 @@ sub _handle_root {
 
     my @server_targets =
         map { { name => $_->getUrl(), date => $_->getFormatedNextRunDate() } }
-        grep { $_->isType('server') }
+        grep { $_->isa('FusionInventory::Agent::Target::Server') }
         $self->{agent}->getTargets();
 
     my @local_targets =
         map { { name => $_->getPath(), date => $_->getFormatedNextRunDate() } }
-        grep { $_->isType('local') }
+        grep { $_->isa('FusionInventory::Agent::Target::Local') }
         $self->{agent}->getTargets();
 
     my $hash = {
@@ -189,13 +189,10 @@ sub _handle_deploy {
     }
 
     my $path;
-    my $count = 0;
     LOOP: foreach my $target ($self->{agent}->getTargets()) {
         foreach (File::Glob::bsd_glob($target->{storage}->getDirectory() . "/deploy/fileparts/shared/*")) {
             next unless -f $_.'/'.$subFilePath;
 
-            $count ++;
-
             my $sha = Digest::SHA->new('512');
             $sha->addfile($_.'/'.$subFilePath, 'b');
             next unless $sha->hexdigest eq $sha512;
@@ -208,12 +205,7 @@ sub _handle_deploy {
         $client->send_file_response($path);
         return 200;
     } else {
-        if ($count) {
-            $client->send_error(404);
-        } else {
-            # Report this agent as nothing to share
-            $client->send_error(404, 'Nothing found');
-        }
+        $client->send_error(404);
         return 404;
     }
 }
@@ -227,7 +219,7 @@ sub _handle_now {
 
     BLOCK: {
         foreach my $target ($self->{agent}->getTargets()) {
-            next unless $target->isType('server');
+            next unless $target->isa('FusionInventory::Agent::Target::Server');
             my $url       = $target->getUrl();
             my $addresses = $self->{trust}->{$url};
             next unless isPartOf($clientIp, $addresses, $logger);
