@@ -35,7 +35,8 @@ my %fields = (
     ACCESSLOG        => [ qw/USERID LOGDATE/ ],
 
     ANTIVIRUS        => [ qw/COMPANY ENABLED GUID NAME UPTODATE VERSION
-                             EXPIRATION BASE_CREATION BASE_VERSION/ ],
+                             DATFILECREATION DATFILEVERSION ENGINEVERSION32
+                             ENGINEVERSION64/ ],
     BATTERIES        => [ qw/CAPACITY CHEMISTRY DATE NAME SERIAL MANUFACTURER
                              VOLTAGE/ ],
     CONTROLLERS      => [ qw/CAPTION DRIVER NAME MANUFACTURER PCICLASS VENDORID
@@ -44,8 +45,7 @@ my %fields = (
                              SERIAL STEPPING FAMILYNAME FAMILYNUMBER MODEL
                              SPEED ID EXTERNAL_CLOCK ARCH CORECOUNT/ ],
     DRIVES           => [ qw/CREATEDATE DESCRIPTION FREE FILESYSTEM LABEL
-                             LETTER SERIAL SYSTEMDRIVE TOTAL TYPE VOLUMN
-                             ENCRYPT_NAME ENCRYPT_ALGO ENCRYPT_STATUS ENCRYPT_TYPE/ ],
+                             LETTER SERIAL SYSTEMDRIVE TOTAL TYPE VOLUMN/ ],
     ENVS             => [ qw/KEY VAL/ ],
     INPUTS           => [ qw/NAME MANUFACTURER CAPTION DESCRIPTION INTERFACE
                              LAYOUT POINTINGTYPE TYPE/ ],
@@ -71,8 +71,6 @@ my %fields = (
     PHYSICAL_VOLUMES => [ qw/DEVICE PV_PE_COUNT PV_UUID FORMAT ATTR
                              SIZE FREE PE_SIZE VG_UUID/ ],
     PORTS            => [ qw/CAPTION DESCRIPTION NAME TYPE/ ],
-    POWERSUPPLIES    => [ qw/PARTNUM SERIALNUMBER MANUFACTURER POWER_MAX NAME
-                             HOTREPLACEABLE PLUGGED STATUS LOCATION MODEL/ ],
     PRINTERS         => [ qw/COMMENT DESCRIPTION DRIVER NAME NETWORK PORT
                              RESOLUTION SHARED STATUS ERRSTATUS SERVERNAME
                              SHARENAME PRINTPROCESSOR SERIAL/ ],
@@ -90,8 +88,7 @@ my %fields = (
     SOUNDS           => [ qw/CAPTION DESCRIPTION MANUFACTURER NAME/ ],
     STORAGES         => [ qw/DESCRIPTION DISKSIZE INTERFACE MANUFACTURER MODEL
                             NAME TYPE SERIAL SERIALNUMBER FIRMWARE SCSI_COID
-                            SCSI_CHID SCSI_UNID SCSI_LUN WWN
-                            ENCRYPT_NAME ENCRYPT_ALGO ENCRYPT_STATUS ENCRYPT_TYPE/ ],
+                            SCSI_CHID SCSI_UNID SCSI_LUN WWN/ ],
     VIDEOS           => [ qw/CHIPSET MEMORY NAME RESOLUTION PCISLOT PCIID/ ],
     USBDEVICES       => [ qw/VENDORID PRODUCTID MANUFACTURER CAPTION SERIAL
                             CLASS SUBCLASS NAME/ ],
