@@ -17,7 +17,6 @@ sub new {
         logger       => $params{logger} ||
                         FusionInventory::Agent::Logger->new(),
         maxDelay     => $params{maxDelay} || 3600,
-        errMaxDelay  => $params{delaytime},
         initialDelay => $params{delaytime},
     };
     bless $self, $class;
@@ -62,6 +61,7 @@ sub getStorage {
 sub setNextRunDate {
     my ($self, $nextRunDate) = @_;
 
+    lock($self->{nextRunDate}) if $self->{shared};
     $self->{nextRunDate} = $nextRunDate;
     $self->_saveState();
 }
@@ -69,14 +69,12 @@ sub setNextRunDate {
 sub setNextRunDateFromNow {
     my ($self, $nextRunDelay) = @_;
 
+    lock($self->{nextRunDate}) if $self->{shared};
     if ($nextRunDelay) {
         # While using nextRunDelay, we double it on each consecutive call until
         # delay reach target defined maxDelay. This is only used on network failure.
         $nextRunDelay = 2 * $self->{_nextrundelay} if ($self->{_nextrundelay});
         $nextRunDelay = $self->getMaxDelay() if ($nextRunDelay > $self->getMaxDelay());
-        # Also limit toward the initial delaytime as it is also used to
-        # define the maximum delay on network error
-        $nextRunDelay = $self->{errMaxDelay} if ($nextRunDelay > $self->{errMaxDelay});
         $self->{_nextrundelay} = $nextRunDelay;
     }
     $self->{nextRunDate} = time + ($nextRunDelay || 0);
@@ -86,6 +84,7 @@ sub setNextRunDateFromNow {
 sub resetNextRunDate {
     my ($self) = @_;
 
+    lock($self->{nextRunDate}) if $self->{shared};
     $self->{_nextrundelay} = 0;
     $self->{nextRunDate} = $self->_computeNextRunDate();
     $self->_saveState();
@@ -94,9 +93,6 @@ sub resetNextRunDate {
 sub getNextRunDate {
     my ($self) = @_;
 
-    # Check if state file has been updated by a third party, like a script run
-    $self->_loadState() if $self->_needToReloadState();
-
     return $self->{nextRunDate};
 }
 
@@ -138,17 +134,6 @@ sub setMaxDelay {
     $self->_saveState();
 }
 
-sub isType {
-    my ($self, $testtype) = @_;
-
-    return unless $testtype;
-
-    my $type = $self->getType()
-        or return;
-
-    return "$type" eq "$testtype";
-}
-
 # compute a run date, as current date and a random delay
 # between maxDelay / 2 and maxDelay
 sub _computeNextRunDate {
@@ -189,17 +174,6 @@ sub _saveState {
     );
 }
 
-sub _needToReloadState {
-    my ($self) = @_;
-
-    # Only re-check if it's time to reload after 30 seconds
-    return if $self->{_next_reload_check} && time < $self->{_next_reload_check};
-
-    $self->{_next_reload_check} = time+30;
-
-    return $self->{storage}->modified(name => 'target');
-}
-
 1;
 __END__
 
