@@ -32,29 +32,18 @@ sub getPath {
     return $self->{path};
 }
 
-sub getName {
+sub _getName {
     my ($self) = @_;
 
     return $self->{path};
 }
 
-sub getType {
+sub _getType {
     my ($self) = @_;
 
     return 'local';
 }
 
-sub plannedTasks {
-    my $self = shift @_;
-
-    # Keep only inventory as local task
-    if (@_) {
-        $self->{tasks} = [ grep { $_ =~ /^Inventory$/i } @_ ];
-    }
-
-    return @{$self->{tasks} || []};
-}
-
 1;
 
 __END__
@@ -86,17 +75,3 @@ the output directory path (mandatory)
 =head2 getPath()
 
 Return the local output directory for this target.
-
-=head2 getName()
-
-Return the target name
-
-=head2 getType()
-
-Return the target type
-
-=head2 plannedTasks([@tasks])
-
-Initializes target tasks with supported ones if a list of tasks is provided
-
-Return an array of planned tasks.
