@@ -61,7 +61,7 @@ my %json_validation = (
 sub isEnabled {
     my ($self) = @_;
 
-    if (!$self->{target}->isType('server')) {
+    if (!$self->{target}->isa('FusionInventory::Agent::Target::Server')) {
         $self->{logger}->debug("Collect task not compatible with local target");
         return;
     }
