@@ -60,10 +60,9 @@ sub getPartFilePath {
 
 # Compute a directory name that will be used to know
 # if the file must be purge. We don't want a new directory
-# everytime, so we use a one minute time frame to follow the retention duration unit
-    my $expiration    = time + (($self->{retention_duration}+1) * 60);
-    my $retentiontime = $expiration - $expiration % 60 ;
-    $filePath .= $retentiontime . '/' . $subFilePath;
+# everytime, so we use a 10h frame
+    $filePath .= int(time/10000)*10000 + ($self->{retention_duration} * 60);
+    $filePath .= '/'.$subFilePath;
 
     return $filePath;
 }
@@ -80,13 +79,10 @@ sub download {
             $self->{logger}->debug("can't enable P2P: $EVAL_ERROR")
         } else {
             my $p2p = FusionInventory::Agent::Task::Deploy::P2P->new(
-                scan_timeout    => 1,
-                datastore       => $self->{datastore},
-                logger          => $self->{logger}
+                logger => $self->{logger}
             );
             eval {
                 @peers = $p2p->findPeers(62354);
-                $self->{p2pnet} = $p2p;
             };
             $self->{logger}->debug("failed to enable P2P: $EVAL_ERROR")
                 if $EVAL_ERROR;
@@ -94,7 +90,6 @@ sub download {
     };
 
     my $lastPeer;
-    my $nextPathUpdate = _getNextPathUpdateTime();
     PART: foreach my $sha512 (@{$self->{multiparts}}) {
         my $path = $self->getPartFilePath($sha512);
         if (-f $path) {
@@ -115,41 +110,26 @@ sub download {
                 $lastPeer = $peer;
                 next PART;
             }
-            # Update filepath so retention is kept in the future on long search
-            if ( time - $nextPathUpdate > 0 ) {
-                $path = $self->getPartFilePath($sha512);
-                $nextPathUpdate = _getNextPathUpdateTime();
-            }
         }
 
         # try to download from mirrors
         foreach my $mirror (@{$self->{mirrors}}) {
             my $success = $self->_download($mirror, $sha512, $path);
             next PART if $success;
-            # Update filepath so retention is kept in the future on long search
-            if ( time - $nextPathUpdate > 0 ) {
-                $path = $self->getPartFilePath($sha512);
-                $nextPathUpdate = _getNextPathUpdateTime();
-            }
         }
     }
 }
 
-sub _getNextPathUpdateTime {
-    my $time = time;
-    return $time + 60 - $time % 60;
-}
-
 sub _downloadPeer {
     my ($self, $peer, $sha512, $path) = @_;
 
     my $source = 'http://'.$peer.':62354/deploy/getFile/';
 
-    return $self->_download($source, $sha512, $path, $peer);
+    return $self->_download($source, $sha512, $path);
 }
 
 sub _download {
-    my ($self, $source, $sha512, $path, $peer) = @_;
+    my ($self, $source, $sha512, $path) = @_;
 
     return unless $sha512 =~ /^(.)(.)/;
     my $sha512dir = $1.'/'.$1.$2.'/';
@@ -158,19 +138,9 @@ sub _download {
     $self->{logger}->debug($url);
 
     my $request = HTTP::Request->new(GET => $url);
-    # We want to try direct download without proxy if peer if defined and then
-    # we also prefer to use really short timeout to disqualify busy peers and
-    # also avoid to block for not responding peers while using P2P
-    my $timeout = $peer ? 1 : 180 ;
-    my $response = $self->{client}->request($request, $path, $peer, $timeout);
+    my $response = $self->{client}->request($request, $path);
 
-    if ($response->code != 200) {
-        if ($response->code != 404 || $response->status_line() =~ /Nothing found/) {
-            $self->{logger}->debug2("Remote peer $peer is useless, we should forget it out for a while");
-            $self->{p2pnet}->forgetPeer($peer) if $self->{p2pnet};
-        }
-        return;
-    }
+    return if $response->code != 200;
     return if ! -f $path;
 
     if ($self->_getSha512ByFile($path) ne $sha512) {
