@@ -3,9 +3,9 @@ package FusionInventory::Agent::Task::Inventory::AIX;
 use strict;
 use warnings;
 
-use English qw(-no_match_vars);
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
 
-use List::Util qw(first);
+use English qw(-no_match_vars);
 
 use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::AIX;
