@@ -7,7 +7,6 @@ use parent 'FusionInventory::Agent::Task::Inventory::Module';
 
 use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Generic;
-use FusionInventory::Agent::Tools::Batteries;
 
 sub isEnabled {
     my (%params) = @_;
@@ -21,54 +20,47 @@ sub doInventory {
     my $inventory = $params{inventory};
     my $logger    = $params{logger};
 
-    foreach my $battery (_getBatteries(logger => $logger)) {
-        $inventory->addEntry(
-            section => 'BATTERIES',
-            entry   => $battery
-        );
-    }
+    my $battery = _getBattery(logger => $logger);
+
+    return unless $battery;
+
+    $inventory->addEntry(
+        section => 'BATTERIES',
+        entry   => $battery
+    );
 }
 
-sub _getBatteries {
+sub _getBattery {
     my $infos = getDmidecodeInfos(@_);
 
     return unless $infos->{22};
 
-    my @batteries = ();
-    foreach my $info (@{$infos->{22}}) {
-        my $battery = _extractBatteryData($info);
-        push @batteries, $battery if $battery;
-    }
-
-    return @batteries;
-}
-
-sub _extractBatteryData {
-    my ($info) = @_;
+    my $info    = $infos->{22}->[0];
 
     my $battery = {
         NAME         => $info->{'Name'},
-        MANUFACTURER => getCanonicalManufacturer($info->{'Manufacturer'}),
-        SERIAL       => sanitizeBatterySerial(
-            $info->{'Serial Number'} || $info->{'SBDS Serial Number'}
-        ),
+        MANUFACTURER => $info->{'Manufacturer'},
+        SERIAL       => $info->{'Serial Number'} ||
+                        $info->{'SBDS Serial Number'},
         CHEMISTRY    => $info->{'Chemistry'} ||
-            $info->{'SBDS Chemistry'},
+                        $info->{'SBDS Chemistry'},
     };
 
-    if ($info->{'Manufacture Date'}) {
+    if      ($info->{'Manufacture Date'}) {
         $battery->{DATE} = _parseDate($info->{'Manufacture Date'});
     } elsif ($info->{'SBDS Manufacture Date'}) {
         $battery->{DATE} = _parseDate($info->{'SBDS Manufacture Date'});
     }
 
-    my $voltage  = getCanonicalVoltage($info->{'Design Voltage'});
-    $battery->{VOLTAGE} = $voltage
-        if $voltage;
+    if ($info->{'Design Capacity'} &&
+        $info->{'Design Capacity'} =~ /(\d+) \s m[WA]h$/x) {
+        $battery->{CAPACITY} = $1;
+    }
 
-    my $capacity = getCanonicalCapacity($info->{'Design Capacity'}, $voltage);
-    $battery->{CAPACITY} = $capacity
-        if $capacity;
+    if ($info->{'Design Voltage'} &&
+        $info->{'Design Voltage'} =~ /(\d+) \s mV$/x) {
+        $battery->{VOLTAGE} = $1;
+    }
 
     return $battery;
 }
