@@ -51,17 +51,6 @@ sub _getDisplays {
 
     foreach my $videoName (keys %{$infos->{'Graphics/Displays'}}) {
         my $videoCardInfo = $infos->{'Graphics/Displays'}->{$videoName};
-
-        my $memory = $videoCardInfo->{'VRAM (Total)'} ||
-            $videoCardInfo->{'VRAM (Dynamic, Max)'};
-        $memory =~ s/\ .*//g if $memory;
-
-        my $video = {
-            CHIPSET    => $videoCardInfo->{'Chipset Model'},
-            MEMORY     => $memory,
-            NAME       => $videoName
-        };
-
         foreach my $displayName (keys %{$videoCardInfo->{Displays}}) {
             next if $displayName eq 'Display Connector';
             next if $displayName eq 'Display';
@@ -69,33 +58,26 @@ sub _getDisplays {
 
             my $resolution = $displayInfo->{Resolution};
             if ($resolution) {
-                my ($x,$y) = $resolution =~ /(\d+) *x *(\d+)/;
-                $resolution = $x.'x'.$y if $x && $y;
+                $resolution =~ s/\ //g;
+                $resolution =~ s/\@.*//g;
             }
 
-            my $monitor = {
-                CAPTION => $displayName
+            my $memory = $videoCardInfo->{'VRAM (Total)'};
+            $memory =~ s/\ .*//g if $memory;
+
+            push @videos, {
+                CHIPSET    => $videoCardInfo->{'Chipset Model'},
+                MEMORY     => $memory,
+                NAME       => $videoName,
+                RESOLUTION => $resolution,
+                PCISLOT    => $videoCardInfo->{Slot}
             };
 
-            my $serial = getSanitizedString($displayInfo->{'Display Serial Number'});
-            $monitor->{SERIAL} = $serial if $serial;
-
-            my $description = getSanitizedString($displayInfo->{'Display Type'});
-            $monitor->{DESCRIPTION} = $description if $description;
-
-            push @monitors, $monitor;
-
-            # Set first found resolution on associated video card
-            $video->{RESOLUTION} = $resolution
-                if $resolution && !$video->{RESOLUTION};
+            push @monitors, {
+                CAPTION     => $displayName,
+                DESCRIPTION => $displayName,
+            }
         }
-
-        $video->{PCISLOT} = $videoCardInfo->{Bus}
-            if defined($videoCardInfo->{Bus});
-        $video->{PCISLOT} = $videoCardInfo->{Slot}
-            if defined($videoCardInfo->{Slot});
-
-        push @videos, $video;
     }
 
     return (
