@@ -3,6 +3,8 @@ package FusionInventory::Agent::Task::Inventory::Solaris::Drives;
 use strict;
 use warnings;
 
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
+
 use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Unix;
 
@@ -18,10 +20,13 @@ sub doInventory {
     my $inventory = $params{inventory};
     my $logger    = $params{logger};
 
+    my $df_version = $params{df_version} ||
+        getFirstLine(logger => $logger, command => "df --version");
+
     # get filesystems list
-    my $line = getFirstLine(logger => $logger, command => "df --version");
+
     # df --help is on STDERR on some system, so $line may be undef
-    my $command = $line && $line =~ /GNU/ ? "df -P -k" : "df -k";
+    my $command = $df_version && $df_version =~ /GNU/ ? "df -P -k" : "df -k";
 
     my @filesystems =
         # exclude solaris 10 specific devices
@@ -29,12 +34,14 @@ sub doInventory {
         # exclude cdrom mount
         grep { $_->{TYPE} !~ /cdrom/ }
         # get all file systems
-        getFilesystemsFromDf(logger => $logger, command => $command);
+        getFilesystemsFromDf(command => $command, %params);
 
     # get indexed list of filesystems types
     my %filesystems_types =
         map { /^(\S+) on \S+ type (\w+)/; $1 => $2 }
-        getAllLines(logger => $logger, command => '/usr/sbin/mount -v');
+            $params{mount_res} ?
+                getAllLines(logger => $logger, file => $params{mount_res}) :
+                getAllLines(logger => $logger, command => '/usr/sbin/mount -v');
 
     # set filesystem type based on that information
     foreach my $filesystem (@filesystems) {
@@ -48,6 +55,8 @@ sub doInventory {
 
     # add filesystems to the inventory
     foreach my $filesystem (@filesystems) {
+        # Skip if filesystem is lofs
+        next if $filesystem->{FILESYSTEM} eq 'lofs';
         $inventory->addEntry(
             section => 'DRIVES',
             entry   => $filesystem
