@@ -4,8 +4,11 @@ package FusionInventory::Agent::Task::Inventory::Virtualization::Qemu;
 use strict;
 use warnings;
 
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
+
 use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Unix;
+use FusionInventory::Agent::Tools::Virtualization;
 
 sub isEnabled {
     # Avoid duplicated entry with libvirt
@@ -75,7 +78,7 @@ sub doInventory {
                 UUID      => $values->{uuid},
                 VCPU      => 1,
                 MEMORY    => $values->{mem},
-                STATUS    => "running",
+                STATUS    => STATUS_RUNNING,
                 SUBSYSTEM => $values->{vmtype},
                 VMTYPE    => $values->{vmtype},
                 SERIAL    => $values->{serial},
