@@ -3,7 +3,10 @@ package FusionInventory::Agent::Task::Inventory::Virtualization::XenCitrixServer
 use strict;
 use warnings;
 
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
+
 use FusionInventory::Agent::Tools;
+use FusionInventory::Agent::Tools::Virtualization;
 
 our $runMeIfTheseChecksFailed = ["FusionInventory::Agent::Task::Inventory::Virtualization::Libvirt"];
 
@@ -68,8 +71,8 @@ sub  _getVirtualMachines {
 
     # xe status
     my %status_list = (
-        'running' => 'running',
-        'halted'  => 'shutdown',
+        'running' => STATUS_RUNNING,
+        'halted'  => STATUS_SHUTDOWN,
     );
 
     my $machine;
@@ -87,7 +90,7 @@ sub  _getVirtualMachines {
             next;
         }
         if ($extendedlabel =~ /power-state/) {
-            $machine->{STATUS} = $value ? $status_list{$value} : 'off';
+            $machine->{STATUS} = $value ? $status_list{$value} : STATUS_OFF;
             next;
         }
         if ($extendedlabel =~ /VCPUs-number/) {
