@@ -47,9 +47,7 @@ sub doInventory {
 sub _getDrives {
     my (%params) = @_;
 
-    my $logger = $params{logger};
-
-    my $systemDrive = "C:";
+    my $systemDrive;
     foreach my $object (getWMIObjects(
         class      => 'Win32_OperatingSystem',
         properties => [ qw/SystemDrive/ ]
@@ -58,6 +56,7 @@ sub _getDrives {
     }
 
     my @drives;
+    my @volumes;
     my %seen;
 
     foreach my $object (getWMIObjects(
@@ -85,7 +84,7 @@ sub _getDrives {
             }
         }
 
-        my $drive = {
+        push @drives, {
             CREATEDATE  => $object->{InstallDate},
             DESCRIPTION => $object->{Description},
             FREE        => $object->{FreeSpace},
@@ -99,9 +98,7 @@ sub _getDrives {
             VOLUMN      => $object->{VolumeName},
         };
 
-        $seen{$object->{DeviceID} || $object->{Caption}} = $drive;
-
-        push @drives, $drive;
+        $seen{$object->{DeviceID} || $object->{Caption}} = 1;
     }
 
     # Scan Win32_Volume to check for mounted point drives
@@ -109,7 +106,7 @@ sub _getDrives {
         class      => 'Win32_Volume',
         properties => [ qw/
             InstallDate Description FreeSpace FileSystem Name Caption DriveLetter
-            SerialNumber Capacity DriveType Label DeviceID
+            SerialNumber Capacity DriveType Label
         / ]
     )) {
         # Skip volume already seen as instance of Win32_LogicalDisk class
@@ -123,7 +120,7 @@ sub _getDrives {
         $object->{Capacity} = int($object->{Capacity} / (1024 * 1024))
             if $object->{Capacity};
 
-        my $drive = {
+        push @volumes, {
             CREATEDATE  => $object->{InstallDate},
             DESCRIPTION => $object->{Description},
             FREE        => $object->{FreeSpace},
@@ -138,49 +135,9 @@ sub _getDrives {
             TYPE        => $type[$object->{DriveType}],
             VOLUMN      => $object->{Label},
         };
-
-        $seen{$object->{DeviceID} || $object->{DriveLetter} || $object->{Caption}} = $drive;
-
-        push @drives, $drive;
     }
 
-    # See https://docs.microsoft.com/en-us/windows/desktop/secprov/getencryptionmethod-win32-encryptablevolume
-    my @encryptionMethod = qw(
-        None            AES_128_WITH_DIFFUSER   AES_256_WITH_DIFFUSER
-        AES_128         AES_256                 HARDWARE_ENCRYPTION
-        XTS_AES_128     XTS_AES_256
-    );
-
-    # Scan Win32_EncryptableVolume to check for BitLocker crypted volumes
-    foreach my $object (getWMIObjects(
-        moniker    => 'winmgmts://./root/CIMV2/Security/MicrosoftVolumeEncryption',
-        class      => 'Win32_EncryptableVolume',
-        properties => [ qw/
-            DeviceID EncryptionMethod ProtectionStatus DriveLetter
-        / ]
-    )) {
-        my $id = $object->{DeviceID};
-        $id = $object->{DriveLetter} unless exists($seen{$id});
-
-        if (!exists($seen{$id})) {
-            $logger->Error("Unknown $id encryptable drive") if $logger;
-            next;
-        }
-
-        my $method = $object->{EncryptionMethod} || 0;
-        my $encryptAlgo = defined($encryptionMethod[$method]) ?
-            $encryptionMethod[$method] : 'Unknown';
-
-        my $encrypted = defined($object->{ProtectionStatus}) ?
-            $object->{ProtectionStatus} : 2 ;
-
-        $seen{$id}->{ENCRYPT_NAME}   = 'BitLocker';
-        $seen{$id}->{ENCRYPT_ALGO}   = $encryptAlgo ;
-        $seen{$id}->{ENCRYPT_STATUS} = $encrypted == 0 ? 'No'  :
-                                       $encrypted == 1 ? 'Yes' : 'Unknown' ;
-    }
-
-    return @drives;
+    return @drives, @volumes;
 }
 
 sub _encodeSerialNumber {
