@@ -3,16 +3,11 @@ package FusionInventory::Agent::Task::Inventory::Win32::Users;
 use strict;
 use warnings;
 
-use constant wbemFlagReturnImmediately => 0x10;
-use constant wbemFlagForwardOnly => 0x20;
+use parent 'FusionInventory::Agent::Task::Inventory::Module';
 
 use English qw(-no_match_vars);
-use Win32::TieRegistry (
-    Delimiter   => '/',
-    ArrayValues => 0,
-    qw/KEY_READ/
-);
 
+use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Win32;
 
 sub isEnabled {
@@ -21,6 +16,12 @@ sub isEnabled {
     return 1;
 }
 
+sub isEnabledForRemote {
+    my (%params) = @_;
+    return 0 if $params{no_category}->{user};
+    return 1;
+}
+
 sub doInventory {
     my (%params) = @_;
 
@@ -47,14 +48,33 @@ sub doInventory {
 
     foreach my $user (_getLoggedUsers(logger => $logger)) {
         $inventory->addEntry(
+            noDuplicated => 1,
             section => 'USERS',
             entry   => $user
         );
     }
 
-    $inventory->setHardware({
-        LASTLOGGEDUSER => _getLastUser(logger => $logger)
-    });
+    my $lastLoggedUser = _getLastUser(logger => $logger);
+    if ($lastLoggedUser) {
+        # Include last logged user as usual computer user
+        if (ref($lastLoggedUser) eq 'HASH') {
+            $inventory->addEntry(
+                noDuplicated => 1,
+                section => 'USERS',
+                entry   => $lastLoggedUser
+            );
+
+            # Obsolete in specs, to be removed with 3.0
+            $inventory->setHardware({
+                LASTLOGGEDUSER => $lastLoggedUser->{LOGIN}
+            });
+        } else {
+            # Obsolete in specs, to be removed with 3.0
+            $inventory->setHardware({
+                LASTLOGGEDUSER => $lastLoggedUser
+            });
+        }
+    }
 }
 
 sub _getLocalUsers {
@@ -67,7 +87,7 @@ sub _getLocalUsers {
 
     foreach my $object (getWMIObjects(
         moniker    => 'winmgmts:\\\\.\\root\\CIMV2',
-        query      => [ $query ],
+        query      => $query,
         properties => [ qw/Name SID/ ])
     ) {
         my $user = {
@@ -90,7 +110,7 @@ sub _getLocalGroups {
 
     foreach my $object (getWMIObjects(
         moniker    => 'winmgmts:\\\\.\\root\\CIMV2',
-        query      => [ $query ],
+        query      => $query,
         properties => [ qw/Name SID/ ])
     ) {
         my $group = {
@@ -105,19 +125,17 @@ sub _getLocalGroups {
 
 sub _getLoggedUsers {
 
-    my @query = (
+    my $query =
         "SELECT * FROM Win32_Process".
         " WHERE ExecutablePath IS NOT NULL" .
-        " AND ExecutablePath LIKE '%\\\\Explorer\.exe'", "WQL",
-        wbemFlagReturnImmediately | wbemFlagForwardOnly ## no critic (ProhibitBitwise)
-    );
+        " AND ExecutablePath LIKE '%\\\\Explorer\.exe'";
 
     my @users;
     my $seen;
 
     foreach my $user (getWMIObjects(
         moniker    => 'winmgmts:\\\\.\\root\\CIMV2',
-        query      => \@query,
+        query      => $query,
         method     => 'GetOwner',
         params     => [ 'name', 'domain' ],
         name       => [ 'string', '' ],
@@ -137,20 +155,51 @@ sub _getLoggedUsers {
 
 sub _getLastUser {
 
-    # ensure native registry access, not the 32 bit view
-    my $flags = is64bit() ? KEY_READ | KEY_WOW64_64 : KEY_READ;
+    my $user;
 
-    my $machKey = $Registry->Open('LMachine', {
-        Access => $flags
-    }) or die "Can't open HKEY_LOCAL_MACHINE key: $EXTENDED_OS_ERROR";
+    return unless any {
+        $user = getRegistryValue(path => "HKEY_LOCAL_MACHINE/$_")
+    } (
+        'SOFTWARE/Microsoft/Windows/CurrentVersion/Authentication/LogonUI/LastLoggedOnSAMUser',
+        'SOFTWARE/Microsoft/Windows/CurrentVersion/Authentication/LogonUI/LastLoggedOnUser',
+        'SOFTWARE/Microsoft/Windows NT/CurrentVersion/Winlogon/DefaultUserName'
+    );
 
-    my $user =
-        encodeFromRegistry($machKey->{"SOFTWARE/Microsoft/Windows/CurrentVersion/Authentication/LogonUI/LastLoggedOnUser"}) ||
-        encodeFromRegistry($machKey->{"SOFTWARE/Microsoft/Windows NT/CurrentVersion/Winlogon/DefaultUserName"});
-    return unless $user;
+    # LastLoggedOnSAMUser becomes the mandatory value to detect last logged on user
+    my @user = $user =~ /^([^\\]*)\\(.*)$/;
+    if ( @user == 2 ) {
+        # Try to get local user from user part if domain is just a dot
+        return $user[0] eq '.' ? _getLocalUser($user[1]) :
+            {
+                LOGIN   => $user[1],
+                DOMAIN  => $user[0]
+            };
+    }
 
+    # Backward compatibility, to be removed for 3.0
     $user =~ s,.*\\,,;
     return $user;
 }
 
+sub _getLocalUser {
+    my ($name) = @_;
+
+    my $query = "SELECT * FROM Win32_UserAccount WHERE LocalAccount = True";
+
+    my @local_users = getWMIObjects(
+        moniker    => 'winmgmts:\\\\.\\root\\CIMV2',
+        query      => $query,
+        properties => [ qw/Name Domain/ ]
+    );
+
+    my $user = first { $_->{Name} eq $name } @local_users;
+
+    return unless $user;
+
+    return {
+        LOGIN   => $user->{Name},
+        DOMAIN  => $user->{Domain}
+    };
+}
+
 1;
