@@ -123,18 +123,18 @@ sub getCanonicalManufacturer {
     if (exists $manufacturers{$manufacturer}) {
         $manufacturer = $manufacturers{$manufacturer};
     } elsif ($manufacturer =~ /(
-        maxtor     |
-        sony       |
-        compaq     |
-        ibm        |
-        toshiba    |
-        fujitsu    |
-        \blg\b     |
-        samsung    |
-        nec        |
-        transcend  |
-        matshita   |
-        hitachi    |
+        maxtor    |
+        sony      |
+        compaq    |
+        ibm       |
+        toshiba   |
+        fujitsu   |
+        lg        |
+        samsung   |
+        nec       |
+        transcend |
+        matshita  |
+        hitachi   |
         pioneer
     )/xi) {
         $manufacturer = ucfirst(lc($1));
@@ -355,7 +355,7 @@ sub getFirstLine {
     my $result = <$handle>;
     close $handle;
 
-    chomp $result if defined $result;
+    chomp $result if $result;
     return $result;
 }
 
@@ -371,7 +371,7 @@ sub getLastLine {
     }
     close $handle;
 
-    chomp $result if defined $result;
+    chomp $result if $result;
     return $result;
 }
 
@@ -829,4 +829,4 @@ Return the content of a given file.
 
 =head2 isParamArrayAndFilled($hash, $paramName)
 
-Return if $hash has a key $paramName which value is a ARRAY ref not empty.
+Return if $hash has a key $paramName which value is a ARRAY ref not empty.
\ No newline at end of file
