@@ -63,7 +63,6 @@ my %sysdescr_first_word = (
     'juniper'        => { manufacturer => 'Juniper',         type => 'NETWORKING' },
     'konica'         => { manufacturer => 'Konica',          type => 'PRINTER'    },
     'kyocera'        => { manufacturer => 'Kyocera',         type => 'PRINTER'    },
-    'lancom'         => { manufacturer => 'Lancom',          type => 'NETWORKING' },
     'lexmark'        => { manufacturer => 'Lexmark',         type => 'PRINTER'    },
     'netapp'         => { manufacturer => 'NetApp',          type => 'STORAGE'    },
     'netgear'        => { manufacturer => 'NetGear',         type => 'NETWORKING' },
@@ -102,6 +101,49 @@ my @sysdescr_rules = (
     },
 );
 
+# rules on model name to reset manufacturer to real vendor
+my %sysmodel_first_word = (
+    'dell'           => { manufacturer => 'Dell', },
+);
+
+# common base variables
+my %base_variables = (
+    CPU          => {
+        oid  => '.1.3.6.1.4.1.9.9.109.1.1.1.1.3.1',
+        type => 'count',
+    },
+    SNMPHOSTNAME => {
+        oid  => [
+            '.1.3.6.1.2.1.1.5.0',
+            '.1.3.6.1.4.1.2699.1.2.1.2.1.1.2.1', # PRINTER-PORT-MONITOR-MIB, ppmPrinterName
+        ],
+        type => 'string',
+    },
+    LOCATION     => {
+        oid  => '.1.3.6.1.2.1.1.6.0',
+        type => 'string',
+    },
+    CONTACT      => {
+        oid  => '.1.3.6.1.2.1.1.4.0',
+        type => 'string',
+    },
+    UPTIME       => {
+        oid  => '.1.3.6.1.2.1.1.3.0',
+        type => 'string',
+    },
+    MEMORY       => {
+        oid  => [
+            '.1.3.6.1.4.1.9.2.1.8.0',
+            '.1.3.6.1.2.1.25.2.3.1.5.1',
+        ],
+        type => 'memory',
+    },
+    RAM          => {
+        oid  => '.1.3.6.1.4.1.9.3.6.6.0',
+        type => 'memory',
+    },
+);
+
 # common interface variables
 my %interface_variables = (
     IFNUMBER         => {
@@ -189,65 +231,40 @@ my %consumable_types = (
 my %printer_pagecounters_variables = (
     TOTAL      => {
         oid   => [
-            '.1.3.6.1.4.1.1347.42.10.1.1.12.1.1', #Kyocera specific counter for printers and MF
-                                                  # If you were really keen you could calculate misfeed rates
-                                                  # based on the difference betwwen this and the default OID
-                                                  # value and use it to flag a call out of service techs.
-                                                  # Hint: Increasing rate = bald paper pickup roller tyres.
+            '.1.3.6.1.4.1.1347.42.2.1.1.1.6.1.1', #Kyocera specific counter
             '.1.3.6.1.2.1.43.10.2.1.4.1.1'        #Default Value
             ]
     },
     BLACK      => {
-        oid   => '.1.3.6.1.4.1.1347.42.2.2.1.1.3.1.1' #Kyocera specific non-MFP counter
+        oid   => '.1.3.6.1.4.1.1347.42.2.1.1.1.7.1.1' #Kyocera specific counter
     },
     COLOR      => {
-        oid   => '.1.3.6.1.4.1.1347.42.2.1.1.1.8.1.1' #Kyocera specific non-MFP counter
+        oid   => '.1.3.6.1.4.1.1347.42.2.1.1.1.8.1.1' #Kyocera specific counter
     },
     RECTOVERSO => { },
     SCANNED    => {
-        oid   => [
-            '.1.3.6.1.4.1.1347.46.10.1.1.5.3',    #Kyocera MFP specific counter ( total scan counter)
-            '.1.3.6.1.4.1.1602.1.11.1.3.1.4.501'  #Canon specific counter
-        ]
+        oid   => '.1.3.6.1.4.1.1347.46.10.1.1.5.3' #Kyocera specific counter ( total scan counter)
     },
     PRINTTOTAL => {
-        oid   => [
-            '.1.3.6.1.4.1.1347.42.3.1.1.1.1.1',   #Kyocera MFP specific counter
-            '.1.3.6.1.4.1.1602.1.11.1.3.1.4.301'  #Canon specific counter
-        ]
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.1.1.1.2' #Kyocera specific counter
     },
     PRINTBLACK => {
-        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.1.1' #Kyocera MFP specific counter
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.1.1' #Kyocera specific counter
     },
     PRINTCOLOR => {
-        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.1.3' #Kyocera MFP specific counter
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.1.2' #Kyocera specific counter
     },
     COPYTOTAL  => {
-        oid   => [
-            '.1.3.6.1.4.1.1347.42.3.1.1.1.1.2',   #Kyocera MFP specific counter
-            '.1.3.6.1.4.1.1602.1.11.1.3.1.4.101'  #Canon specific counter
-        ]
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.1.1.1.2' #Kyocera specific counter
     },
     COPYBLACK  => {
-        oid   => [
-            '.1.3.6.1.4.1.1347.42.3.1.2.1.1.2.1', #Kyocera MFP specific counter
-            '.1.3.6.1.4.1.1602.1.11.1.3.1.4.113'  #Canon specific counter
-        ]
-    },
-    COPYBLACK_A3  => {
-        oid   => '.1.3.6.1.4.1.1602.1.11.1.3.1.4.112' #Canon specific counter
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.2.1' #Kyocera specific counter
     },
     COPYCOLOR  => {
-        oid   => [
-            '.1.3.6.1.4.1.1347.42.3.1.2.1.1.2.3', #Kyocera MFP specific counter
-            '.1.3.6.1.4.1.1602.1.11.1.3.1.4.123'  #Canon specific counter
-        ]
-    },
-    COPYCOLOR_A3  => {
-        oid   => '.1.3.6.1.4.1.1602.1.11.1.3.1.4.122' #Canon specific counter
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.2.1.1.2.2' #Kyocera specific counter
     },
     FAXTOTAL   => {
-        oid   => '.1.3.6.1.4.1.1347.42.3.1.1.1.1.4'  #Kyocera MFP specific counter
+        oid   => '.1.3.6.1.4.1.1347.42.3.1.1.1.1.4'  #Kyocera specific counter
     }
 );
 
@@ -313,9 +330,6 @@ sub _getDevice {
     # regarding sysobjectid in some case, so we pass it as argument
     $device->loadMibSupport($sysobjectid);
 
-    # Set type from MibSupport
-    $device->setType();
-
     # fallback type identification attempt, using type-specific OID presence
     if (!exists $device->{TYPE}) {
          if (
@@ -326,12 +340,55 @@ sub _getDevice {
         }
     }
 
-    # Find and set model and manufacturer
-    $device->setModel();
-    $device->setManufacturer();
+    # fallback model identification attempt, using type-specific OID value
+    if (!exists $device->{MODEL}) {
+        my $model = exists $device->{TYPE} && $device->{TYPE} eq 'PRINTER' ?
+            $snmp->get('.1.3.6.1.2.1.25.3.2.1.3.1')    :
+            exists $device->{TYPE} && $device->{TYPE} eq 'POWER' ?
+            $snmp->get('.1.3.6.1.2.1.33.1.1.5.0')      : # UPS-MIB
+            $snmp->get('.1.3.6.1.2.1.47.1.1.1.1.13.1') ;
+        $device->{MODEL} = getCanonicalString($model) if $model;
+    }
 
-    # Get some common informations like SNMPHOSTNAME, LOCATION, UPTIME and CONTACT
-    $device->setBaseInfos();
+    # fallback manufacturer identification attempt, using type-agnostic OID
+    if (!exists $device->{MANUFACTURER}) {
+        my $manufacturer = $snmp->get('.1.3.6.1.2.1.43.8.2.1.14.1.1');
+        $device->{MANUFACTURER} = $manufacturer if $manufacturer;
+    }
+
+    # reset manufacturer by rule as real vendor based on first model word
+    if (exists $device->{MODEL}) {
+        my ($first_word) = $device->{MODEL} =~ /(\S+)/;
+        my $result = $sysmodel_first_word{lc($first_word)};
+        if ($result && $result->{manufacturer}) {
+            $device->{MANUFACTURER} = $result->{manufacturer};
+        }
+    }
+
+    # remaining informations
+    foreach my $key (keys %base_variables) {
+        my $variable = $base_variables{$key};
+
+        my $raw_value;
+        if (ref $variable->{oid} eq 'ARRAY') {
+            foreach my $oid (@{$variable->{oid}}) {
+                $raw_value = $snmp->get($oid);
+                last if defined $raw_value;
+            }
+        } else {
+            $raw_value = $snmp->get($variable->{oid});
+        }
+        next unless defined $raw_value;
+
+        my $type = $variable->{type};
+        my $value =
+            $type eq 'memory' ? _getCanonicalMemory($raw_value) :
+            $type eq 'string' ? getCanonicalString($raw_value) :
+            $type eq 'count'  ? _getCanonicalCount($raw_value)  :
+                                $raw_value;
+
+        $device->{$key} = $value if defined $value;
+    }
 
     # Cleanup some strings from whitespaces
     foreach my $key (qw(MODEL SNMPHOSTNAME LOCATION CONTACT)) {
@@ -483,9 +540,6 @@ sub getDeviceFullInfo {
     # second, use results to build the object
     $device->{INFO} = $info ;
 
-    # Set other requested infos
-    $device->setInventoryBaseInfos();
-
     _setGenericProperties(
         device => $device,
         snmp   => $snmp,
@@ -573,7 +627,7 @@ sub _setGenericProperties {
                 $type eq 'mac'      ? getCanonicalMacAddress($raw_value) :
                 $type eq 'constant' ? getCanonicalConstant($raw_value)   :
                 $type eq 'string'   ? getCanonicalString($raw_value)     :
-                $type eq 'count'    ? getCanonicalCount($raw_value)      :
+                $type eq 'count'    ? _getCanonicalCount($raw_value)      :
                                       $raw_value;
             $ports->{$suffix}->{$key} = $value
                 if defined $value && $value ne '';
@@ -599,13 +653,13 @@ sub _setGenericProperties {
         next unless $value;
         # safety checks
         if (! exists $ports->{$value}) {
-            $logger->debug(
+            $logger->warning(
                 "unknown interface $value for IP address $suffix, ignoring"
             ) if $logger;
             next;
         }
         if ($suffix !~ /^$ip_address_pattern$/) {
-            $logger->debug("invalid IP address $suffix") if $logger;
+            $logger->error("invalid IP address $suffix") if $logger;
             next;
         }
         $ports->{$value}->{IP} = $suffix;
@@ -647,7 +701,7 @@ sub _setPrinterProperties {
             $type = $consumable_types{$type_id};
         } else {
             # fallback on description
-            my $description = getCanonicalString($descriptions->{$consumable_id});
+            my $description = $descriptions->{$consumable_id};
             $type =
                 $description =~ /maintenance/i ? 'MAINTENANCEKIT' :
                 $description =~ /fuser/i       ? 'FUSERKIT'       :
@@ -656,27 +710,23 @@ sub _setPrinterProperties {
         }
 
         if (!$type) {
-            $logger->debug("unknown consumable type $type_id: " .
-                (getCanonicalString($descriptions->{$consumable_id}) || "no description")
-            ) if $logger;
+            $logger->debug("unknown consumable type $type_id") if $logger;
             next;
         }
 
         if ($type eq 'TONER' || $type eq 'DRUM' || $type eq 'CARTRIDGE' || $type eq 'DEVELOPER') {
             my $color;
-            if ($colors && $color_id) {
+            if ($color_id) {
                 $color = getCanonicalString($colors->{$color_id});
                 if (!$color) {
-                    $logger->debug("invalid consumable color ID $color_id for : " .
-                        (getCanonicalString($descriptions->{$consumable_id}) || "no description")
-                    ) if $logger;
+                    $logger->debug("invalid color ID $color_id") if $logger;
                     next;
                 }
                 # remove space and following char, XML tag does not accept space
                 $color =~ s/\s.*$//;
             } else {
                 # fallback on description
-                my $description = getCanonicalString($descriptions->{$consumable_id});
+                my $description = $descriptions->{$consumable_id};
                 $color =
                     $description =~ /cyan/i           ? 'cyan'    :
                     $description =~ /magenta/i        ? 'magenta' :
@@ -689,20 +739,8 @@ sub _setPrinterProperties {
 
         my $value;
         if ($current == -2) {
-            # A value of -2 means "unknown" according to the RFC - but this
-            # is not NULL - it means "something undetermined between
-            # OK and BAD".
-            # Several makers seem to have grabbed it as a way of indicating
-            # "almost out" for supplies and waste. (Like a vehicle low fuel warning)
-            #
-            # This was previously set to undef - but that was triggering a bug
-            # that caused bad XML to be output and that in turn would block FI4G imports
-            # which in turn would make page counters look strange for the days
-            # when it was happening (zero pages, then a big spike)
-            #
-            # Using "WARNING" should allow print monitoring staff to ensure
-            # replacement items are in stock before they go "BAD"
-            $value = 'WARNING';
+            # A value of -2 means unknown
+            $value = undef;
         } elsif ($current == -3) {
             # A value of -3 means that the printer knows that there is some
             # supply/remaining space, respectively.
@@ -728,7 +766,6 @@ sub _setPrinterProperties {
             }
         }
 
-        next unless defined $value;
         $device->{CARTRIDGES}->{$type} = $value;
     }
 
@@ -739,7 +776,7 @@ sub _setPrinterProperties {
         if (ref $variable->{oid} eq 'ARRAY') {
             foreach my $oid (@{$variable->{oid}}) {
                 $value = $snmp->get($oid);
-                last if defined($value) && isInteger($value);
+                last if $value;
             }
         } else {
             my $oid = $variable->{oid};
@@ -747,7 +784,7 @@ sub _setPrinterProperties {
         }
         next unless defined $value;
         if (!isInteger($value)) {
-            $logger->debug("incorrect counter value $value, check $variable->{mapping} mapping") if $logger;
+            $logger->error("incorrect counter value $value, check $variable->{mapping} mapping") if $logger;
             next;
         }
         $device->{PAGECOUNTERS}->{$key} = $value;
@@ -793,8 +830,6 @@ sub _setNetworkingProperties {
         ports  => $ports,
         logger => $logger
     );
-
-    $device->setComponents();
 }
 
 sub _getPercentValue {
@@ -809,6 +844,22 @@ sub _getPercentValue {
     );
 }
 
+sub _getCanonicalMemory {
+    my ($value) = @_;
+
+    if ($value =~ /^(\d+) KBytes$/) {
+        return int($1 / 1024);
+    } else {
+        return int($value / 1024 / 1024);
+    }
+}
+
+sub _getCanonicalCount {
+    my ($value) = @_;
+
+    return isInteger($value) ? $value  : undef;
+}
+
 sub _getElement {
     my ($oid, $index) = @_;
 
@@ -923,7 +974,7 @@ sub _addKnownMacAddresses {
     foreach my $port_id (keys %$mac_addresses) {
         # safety check
         if (! exists $ports->{$port_id}) {
-            $logger->debug(
+            $logger->error(
                 "invalid interface ID $port_id while setting known mac " .
                 "addresses, aborting"
             ) if $logger;
@@ -994,7 +1045,7 @@ sub _getKnownMacAddressesDeprecatedOids {
     my (%params) = @_;
 
     my $snmp   = $params{snmp};
-
+                
     my $results;
     my $address2mac   = $snmp->walk($params{address2mac});
     my $address2interface = $snmp->walk($params{address2interface});
@@ -1002,7 +1053,7 @@ sub _getKnownMacAddressesDeprecatedOids {
     foreach my $suffix (sort keys %{$address2mac}) {
         my $interface_id = $address2interface->{$suffix};
         next unless defined $interface_id;
-
+ 
         push @{$results->{$interface_id}},
             getCanonicalMacAddress($address2mac->{$suffix});
     }
@@ -1021,8 +1072,8 @@ sub _setConnectedDevices {
         foreach my $interface_id (keys %$lldp_info) {
             # safety check
             if (! exists $ports->{$interface_id}) {
-                $logger->debug(
-                    "LLDP support: unknown interface $interface_id in LLDP info, ignoring"
+                $logger->warning(
+                    "unknown interface $interface_id in LLDP info, ignoring"
                 ) if $logger;
                 next;
             }
@@ -1042,8 +1093,8 @@ sub _setConnectedDevices {
         foreach my $interface_id (keys %$cdp_info) {
             # safety check
             if (! exists $ports->{$interface_id}) {
-                $logger->debug(
-                    "CDP support: unknown interface $interface_id in CDP info, ignoring"
+                $logger->warning(
+                    "unknown interface $interface_id in CDP info, ignoring"
                 ) if $logger;
                 next;
             }
@@ -1053,29 +1104,15 @@ sub _setConnectedDevices {
             my $cdp_connection  = $cdp_info->{$interface_id};
 
             if ($lldp_connection) {
-                my $match = 0;
-
-                # Try different case to find LLDP/CDP connection match
-                if ($lldp_connection->{SYSDESCR} && $cdp_connection->{SYSDESCR} eq $lldp_connection->{SYSDESCR}) {
-                    $match ++;
-                } elsif ($lldp_connection->{SYSNAME} && $cdp_connection->{SYSNAME}) {
-                    my $cdp_test = getCanonicalMacAddress($cdp_connection->{SYSNAME});
-                    if ($cdp_connection->{SYSNAME} eq $lldp_connection->{SYSNAME}) {
-                        $match ++;
-                    } elsif ($lldp_connection->{SYSMAC} && $cdp_test && $lldp_connection->{SYSMAC} eq $cdp_test) {
-                        $match ++;
-                    }
-                }
-
-                if ($match) {
+                if ($cdp_connection->{SYSDESCR} eq $lldp_connection->{SYSDESCR}) {
                     # same device, everything OK
                     foreach my $key (qw/IP MODEL/) {
                         $lldp_connection->{$key} = $cdp_connection->{$key};
                     }
                 } else {
                     # undecidable situation
-                    $logger->debug(
-                        "CDP support: multiple neighbors found by LLDP and CDP for " .
+                    $logger->warning(
+                        "multiple neighbors found by LLDP and CDP for " .
                         "interface $interface_id, ignoring"
                     );
                     delete $port->{CONNECTIONS};
@@ -1094,8 +1131,8 @@ sub _setConnectedDevices {
         foreach my $interface_id (keys %$edp_info) {
             # safety check
             if (! exists $ports->{$interface_id}) {
-                $logger->debug(
-                    "EDP support: unknown interface $interface_id in EDP info, ignoring"
+                $logger->warning(
+                    "unknown interface $interface_id in EDP info, ignoring"
                 ) if $logger;
                 next;
             }
@@ -1112,8 +1149,8 @@ sub _setConnectedDevices {
                     }
                 } else {
                     # undecidable situation
-                    $logger->debug(
-                        "EDP support: multiple neighbors found by LLDP and EDP for " .
+                    $logger->warning(
+                        "multiple neighbors found by LLDP and EDP for " .
                         "interface $interface_id, ignoring"
                     );
                     delete $port->{CONNECTIONS};
@@ -1151,42 +1188,18 @@ sub _getLLDPInfo {
     # $prefix.x.y.z = $value
     # whereas y is either a port or an interface id
 
-    # See LldpChassisIdSubtype textual convention in lldp.mib RFC
-    # We only report macAddress='4' at the moment
-    my %not_supported_subtype = (
-        '1' => "chassis component",
-        '2' => "interface alias",
-        '3' => "port component",
-        '5' => "network address",
-        '6' => "interface name",
-        '7' => "local"
-    );
-
     while (my ($suffix, $mac) = each %{$lldpRemChassisId}) {
         my $sysdescr = getCanonicalString($lldpRemSysDesc->{$suffix});
         my $sysname = getCanonicalString($lldpRemSysName->{$suffix});
         next unless ($sysdescr || $sysname);
 
-        # Skip unexpected suffix format (seen at least on mikrotik devices)
-        if ($suffix =~ /^\d+$/) {
-            $logger->debug2("LLDP support: skipping unsupported suffix interface $suffix")
-                if ($logger);
-            next;
-        }
-
-        # Skip unsupported LldpChassisIdSubtype
+        # We only support macAddress as LldpChassisIdSubtype at the moment
         my $subtype = $ChassisIdSubType->{$suffix} || "n/a";
         unless ($subtype eq '4') {
-            if ($logger) {
-                my $info = ($sysname || "no name") . ", " .
-                    (getCanonicalString($mac) || "no chassis id") . ", " .
-                    ($sysdescr || "no description");
-                if ($not_supported_subtype{$subtype}) {
-                    $logger->debug("LLDP support: skipping $not_supported_subtype{$subtype}: $info");
-                } else {
-                    $logger->debug("LLDP support: ChassisId subtype $subtype not supported for <$info>, please report this issue");
-                }
-            }
+            $logger->debug(
+                "ChassisId subtype $subtype not supported for <$sysdescr>, value was " .
+                ($mac||"n/a") . ", please report this issue"
+            ) if $logger;
             next;
         }
 
@@ -1197,10 +1210,10 @@ sub _getLLDPInfo {
         $connection->{SYSNAME} = $sysname if $sysname;
 
         # portId is either a port number or a port mac address,
-        # duplicating chassisId
+        # duplicating chassiId
         my $portId = $lldpRemPortId->{$suffix};
         if ($portId !~ /^0x/ or length($portId) != 14) {
-            $connection->{IFNUMBER} = getCanonicalString($portId);
+            $connection->{IFNUMBER} = $portId;
         }
 
         my $ifdescr = getCanonicalString($lldpRemPortDesc->{$suffix});
@@ -1230,7 +1243,6 @@ sub _getCDPInfo {
     my $cdpCacheDeviceId   = $snmp->walk('.1.3.6.1.4.1.9.9.23.1.2.1.1.6');
     my $cdpCacheDevicePort = $snmp->walk('.1.3.6.1.4.1.9.9.23.1.2.1.1.7');
     my $cdpCachePlatform   = $snmp->walk('.1.3.6.1.4.1.9.9.23.1.2.1.1.8');
-    my $cdpCacheSysName    = $snmp->walk('.1.3.6.1.4.1.9.9.23.1.2.1.1.17');
 
     # each cdp variable matches the following scheme:
     # $prefix.x.y = $value
@@ -1239,7 +1251,7 @@ sub _getCDPInfo {
     while (my ($suffix, $ip) = each %{$cdpCacheAddress}) {
         my $interface_id = _getElement($suffix, -2);
         $ip = hex2canonical($ip);
-        next if (!defined($ip) || $ip eq '0.0.0.0');
+        next if $ip eq '0.0.0.0';
 
         my $sysdescr = getCanonicalString($cdpCacheVersion->{$suffix});
         my $model    = getCanonicalString($cdpCachePlatform->{$suffix});
@@ -1256,13 +1268,9 @@ sub _getCDPInfo {
         if ($devicePort =~ /^\d+$/) {
             $connection->{IFNUMBER} = $devicePort;
         } else {
-            $connection->{IFDESCR} = getCanonicalString($devicePort);
+            $connection->{IFDESCR} = $devicePort;
         }
 
-        my $sysname = getCanonicalString($cdpCacheSysName->{$suffix});
-        $connection->{SYSNAME} = $sysname
-            if $sysname;
-
         # cdpCacheDeviceId is either remote host name, either remote mac address
         my $deviceId = $cdpCacheDeviceId->{$suffix};
         if ($deviceId =~ /^0x/) {
@@ -1270,33 +1278,23 @@ sub _getCDPInfo {
                 # let's assume it is a mac address if the length is 6 bytes
                 $connection->{SYSMAC} = lc(alt2canonical($deviceId));
             } else {
-                # otherwise it's may be an hex-encode hostname
-                $deviceId = getCanonicalString($deviceId);
-                if ($deviceId =~ /^[0-9A-Fa-f]{12}$/) {
-                    # let's assume it is a mac address if the length is 12 chars
-                    $connection->{SYSMAC} = lc(alt2canonical($deviceId));
-                } elsif (!$connection->{SYSNAME}) {
-                    $connection->{SYSNAME} = $deviceId;
-                }
+                # otherwise it's an hex-encode hostname
+                $connection->{SYSNAME} = getCanonicalString($deviceId);
             }
-        } elsif (!$connection->{SYSNAME}) {
+        } else {
             $connection->{SYSNAME} = $deviceId;
         }
 
         if ($connection->{SYSNAME} &&
             $connection->{SYSNAME} =~ /^SIP([A-F0-9a-f]*)$/) {
-            $connection->{SYSMAC} = lc(alt2canonical("0x".$1));
-        } elsif ($connection->{SYSNAME} &&
-            $connection->{SYSNAME} =~ /^SIP-(.*)$/ &&
-            $deviceId =~ /^$1([0-9A-Fa-f]{12})$/) {
-            $connection->{SYSMAC} = lc(alt2canonical("0x".$1));
+            $connection->{MAC} = lc(alt2canonical("0x".$1));
         }
 
         # warning: multiple neighbors announcement for the same interface
         # usually means a non-CDP aware intermediate equipement
         if ($results->{$interface_id}) {
-            $logger->debug(
-                "CDP support: multiple neighbors found by CDP for interface $interface_id," .
+            $logger->warning(
+                "multiple neighbors found by CDP for interface $interface_id," .
                 " ignoring"
             );
             $blacklist->{$interface_id} = 1;
@@ -1334,7 +1332,7 @@ sub _getEDPInfo {
     # - z1.z2...zz: the vlan name in ASCII
 
     while (my ($suffix, $ip) = each %{$edpNeighborVlanIpAddress}) {
-        next if (!defined($ip) || $ip eq '0.0.0.0');
+        next if $ip eq '0.0.0.0';
 
         my $interface_id = _getElement($suffix, 0);
         my @mac_elements = _getElements($suffix, 3, 8);
@@ -1342,16 +1340,16 @@ sub _getEDPInfo {
 
         my $connection = {
             IP       => $ip,
-            IFDESCR  => getCanonicalString($edpNeighborPort->{$short_suffix}),
-            SYSNAME  => getCanonicalString($edpNeighborName->{$short_suffix}),
+            IFDESCR  => $edpNeighborPort->{$short_suffix},
+            SYSNAME  => $edpNeighborName->{$short_suffix},
             SYSMAC   => sprintf "%02x:%02x:%02x:%02x:%02x:%02x", @mac_elements
         };
 
         # warning: multiple neighbors announcement for the same interface
         # usually means a non-EDP aware intermediate equipement
         if ($results->{$interface_id}) {
-            $logger->debug(
-                "EDP support: multiple neighbors found by EDP for interface $interface_id," .
+            $logger->warning(
+                "multiple neighbors found by EDP for interface $interface_id," .
                 " ignoring"
             );
             $blacklist->{$interface_id} = 1;
@@ -1366,12 +1364,12 @@ sub _getEDPInfo {
     return $results;
 }
 
+
 sub _setVlans {
     my (%params) = @_;
 
     my $vlans = _getVlans(
         snmp  => $params{snmp},
-        ports => $params{ports}
     );
     return unless $vlans;
 
@@ -1381,10 +1379,10 @@ sub _setVlans {
     foreach my $port_id (keys %$vlans) {
         # safety check
         if (! exists $ports->{$port_id}) {
-            $logger->debug(
-                "invalid interface ID $port_id while setting vlans, skipping"
+            $logger->error(
+                "invalid interface ID $port_id while setting vlans, aborting"
             ) if $logger;
-            next;
+            last;
         }
         $ports->{$port_id}->{VLANS}->{VLAN} = $vlans->{$port_id};
     }
@@ -1394,7 +1392,6 @@ sub _getVlans {
     my (%params) = @_;
 
     my $snmp = $params{snmp};
-    my $ports = $params{ports};
 
     my $results;
     my $vtpVlanName  = $snmp->walk('.1.3.6.1.4.1.9.9.46.1.3.1.1.4.1');
@@ -1408,7 +1405,7 @@ sub _getVlans {
         foreach my $suffix (sort keys %{$vmPortStatus}) {
             my $port_id = _getElement($suffix, -1);
             my $vlan_id = $vmPortStatus->{$suffix};
-            my $name    = getCanonicalString($vtpVlanName->{$vlan_id});
+            my $name    = $vtpVlanName->{$vlan_id};
 
             push @{$results->{$port_id}}, {
                 NUMBER => $vlan_id,
@@ -1417,105 +1414,35 @@ sub _getVlans {
         }
     }
 
-    # For Switch with dot1qVlanStaticEntry and dot1qVlanCurrent Present
-    my $dot1qVlanStaticName = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.3.1.1');
-    my $dot1qVlanStaticEgressPorts = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.3.1.2');
-    my $dot1qVlanStaticUntaggedPorts = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.3.1.4');
-    my $dot1qVlanStaticRowStatus = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.3.1.5');
-    # each result matches either of the following schemes :
-    # $prefix.$i    = $value with $i as vlan_id, and each bit of $value represent the Egress (or Untagged) is present (1st bit = ifnumber 1, 2nd bit => ifnumber 2, etc...)
-    my $dot1qVlanCurrentEgressPorts = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.2.1.4');
-    my $dot1qVlanCurrentUntaggedPorts = $snmp->walk('.1.3.6.1.2.1.17.7.1.4.2.1.5');
-
-    if ($dot1qVlanStaticName && $dot1qVlanStaticRowStatus) {
-        foreach my $vlan_id (sort keys %{$dot1qVlanStaticRowStatus}) {
-            if ($dot1qVlanStaticRowStatus->{$vlan_id} eq 1) {
-                my $name = getCanonicalString($dot1qVlanStaticName->{$vlan_id});
-
-                my ($suffix, $EgressPorts);
-                if ($dot1qVlanCurrentEgressPorts) {
-                    $suffix = defined($dot1qVlanCurrentEgressPorts->{$vlan_id}) ? $vlan_id : "0.".$vlan_id;
-                    # Suffix may not start by "0." for other vendors
-                    unless (defined($dot1qVlanCurrentEgressPorts->{$suffix})) {
-                        ($suffix) = grep { /\.$vlan_id$/ } keys(%{$dot1qVlanCurrentEgressPorts});
-                    }
-                    if ($suffix && defined($dot1qVlanCurrentEgressPorts->{$suffix})) {
-                        $EgressPorts = $dot1qVlanCurrentEgressPorts->{$suffix};
-                    }
-                }
-                if (!defined($EgressPorts)) {
-                    if ($dot1qVlanStaticEgressPorts && defined($dot1qVlanStaticEgressPorts->{$vlan_id})) {
-                        $EgressPorts = $dot1qVlanStaticEgressPorts->{$vlan_id};
-                    } else {
-                        next;
-                    }
-                }
-
-                # Tagged & Untagged VLAN
-                my $bEgress = unpack("B*", hex2char($EgressPorts));
-                my @bEgress = split(//,$bEgress);
-                next unless @bEgress;
-
-                my $UntaggedPorts;
-                if ($suffix && $dot1qVlanCurrentUntaggedPorts && defined($dot1qVlanCurrentUntaggedPorts->{$suffix})) {
-                    $UntaggedPorts = $dot1qVlanCurrentUntaggedPorts->{$suffix};
-                } elsif ($dot1qVlanStaticUntaggedPorts && defined($dot1qVlanStaticUntaggedPorts->{$vlan_id})) {
-                    $UntaggedPorts = $dot1qVlanStaticUntaggedPorts->{$vlan_id};
-                } else {
-                    next;
-                }
-
-                # Untagged VLAN
-                my $bUntagged = unpack("B*", hex2char($UntaggedPorts));
-                my @bUntagged = split(//,$bUntagged);
-                next unless @bUntagged;
-
-                foreach my $port_id (keys %{$ports}) {
-                    next if $port_id > @bEgress || $port_id > @bUntagged;
-                    my $port_index = $port_id - 1;
-                    my $isUntagged = $bUntagged[$port_index];
-                    my $isTagged   = $isUntagged eq '0' ? $bEgress[$port_index] : '0';
-                    push @{$results->{$port_id}}, {
-                        NUMBER  => $vlan_id,
-                        NAME    => $name,
-                        TAGGED  => $isTagged
-                    } if $isTagged || $isUntagged;
+    # For other switches, we use another methods
+    # used for Alcatel-Lucent and ExtremNetworks (and perhaps others)
+    my $vlanIdName = $snmp->walk('.1.0.8802.1.1.2.1.5.32962.1.2.3.1.2');
+    my $portLink = $snmp->walk('.1.0.8802.1.1.2.1.3.7.1.3');
+    if($vlanIdName && $portLink){
+        foreach my $suffix (sort keys %{$vlanIdName}) {
+            my ($port, $vlan) = split(/\./, $suffix);
+            if ($portLink->{$port}) {
+                # case generic where $portLink = port number
+                my $portnumber = $portLink->{$port};
+                # case Cisco where $portLink = port name
+                unless ($portLink->{$port} =~ /^[0-9]+$/) {
+                    $portnumber = $port;
                 }
+                push @{$results->{$portnumber}}, {
+                    NUMBER => $vlan,
+                    NAME   => $vlanIdName->{$suffix}
+                };
             }
         }
-    }
-
-    unless ($results) {
-        # For other switches, we use another methods
-        # used for Alcatel-Lucent and ExtremNetworks (and perhaps others)
-        my $vlanIdName = $snmp->walk('.1.0.8802.1.1.2.1.5.32962.1.2.3.1.2');
-        my $portLink = $snmp->walk('.1.0.8802.1.1.2.1.3.7.1.3');
-        if ($vlanIdName && $portLink) {
-            foreach my $suffix (sort keys %{$vlanIdName}) {
-                my ($port, $vlan) = split(/\./, $suffix);
-                if ($portLink->{$port}) {
-                    # case generic where $portLink = port number
-                    my $portnumber = $portLink->{$port};
-                    # case Cisco where $portLink = port name
-                    unless ($portLink->{$port} =~ /^[0-9]+$/) {
-                        $portnumber = $port;
-                    }
-                    push @{$results->{$portnumber}}, {
-                        NUMBER => $vlan,
-                        NAME   => getCanonicalString($vlanIdName->{$suffix})
-                    };
-                }
-            }
-        } else {
-            # A last method
-            my $vlanId = $snmp->walk('.1.0.8802.1.1.2.1.5.32962.1.2.1.1.1');
-            if ($vlanId) {
-                foreach my $port (sort keys %{$vlanId}) {
-                    push @{$results->{$port}}, {
-                        NUMBER => $vlanId->{$port},
-                        NAME   => "VLAN " . $vlanId->{$port}
-                    };
-                }
+    } else {
+        # A last method
+        my $vlanId = $snmp->walk('.1.0.8802.1.1.2.1.5.32962.1.2.1.1.1');
+        if($vlanId){
+            foreach my $port (sort keys %{$vlanId}) {
+                push @{$results->{$port}}, {
+                    NUMBER => $vlanId->{$port},
+                    NAME   => "VLAN " . $vlanId->{$port}
+                };
             }
         }
     }
@@ -1537,7 +1464,7 @@ sub _setTrunkPorts {
     foreach my $port_id (keys %$trunk_ports) {
         # safety check
         if (! exists $ports->{$port_id}) {
-            $logger->debug(
+            $logger->error(
                 "invalid interface ID $port_id while setting trunk flag, " .
                 "aborting"
             ) if $logger;
@@ -1615,7 +1542,7 @@ sub _setAggregatePorts {
         foreach my $interface_id (keys %$lacp_info) {
             # safety check
             if (!$ports->{$interface_id}) {
-                $logger->debug(
+                $logger->warning(
                     "unknown interface $interface_id in LACP info, ignoring"
                 ) if $logger;
                 next;
@@ -1629,7 +1556,7 @@ sub _setAggregatePorts {
         foreach my $interface_id (keys %$pagp_info) {
             # safety check
             if (!$ports->{$interface_id}) {
-                $logger->debug(
+                $logger->error(
                     "unknown interface $interface_id in PAGP info, ignoring"
                 ) if $logger;
                 next;
