@@ -11,10 +11,7 @@ our @EXPORT = qw(
     getCanonicalString
     getCanonicalMacAddress
     getCanonicalConstant
-    getCanonicalMemory
-    getCanonicalCount
     isInteger
-    getRegexpOidMatch
 );
 
 sub getCanonicalSerialNumber {
@@ -42,20 +39,17 @@ sub getCanonicalString {
     $value =~ s/^\\?["']//;
     $value =~ s/\\?["']$//;
 
+    return unless defined $value;
+
     # Be sure to work on utf-8 string
     $value = getUtf8String($value);
 
-    return unless defined $value;
-
     # reduce linefeeds which can be found in descriptions or comments
     $value =~ s/\p{Control}+\n/\n/g;
 
     # truncate after first invalid character but keep newline as valid
     $value =~ s/[^\p{Print}\n].*$//;
 
-    # Finally cleanup EOL if some is remaining at the end
-    chomp($value);
-
     return $value;
 }
 
@@ -68,7 +62,7 @@ sub getCanonicalMacAddress {
     my @bytes;
 
     # packed value, convert from binary to hexadecimal
-    if ($value =~ m/\A [[:ascii:]] \Z/xms || length($value) == 6) {
+    if ($value =~ m/\A [[:ascii:]] \Z/xms) {
         $value = unpack 'H*', $value;
     }
 
@@ -107,25 +101,6 @@ sub isInteger {
     return $value =~ /^[+-]?\d+$/;
 }
 
-sub getCanonicalMemory {
-    my ($value) = @_;
-
-    # Don't try to analyse negative values
-    return if $value =~ /^-/;
-
-    if ($value =~ /^(\d+) KBytes$/) {
-        return int($1 / 1024);
-    } else {
-        return int($value / 1024 / 1024);
-    }
-}
-
-sub getCanonicalCount {
-    my ($value) = @_;
-
-    return isInteger($value) ? $value  : undef;
-}
-
 sub getCanonicalConstant {
     my ($value) = @_;
 
@@ -133,17 +108,6 @@ sub getCanonicalConstant {
     return $1 if $value =~ /\((\d+)\)$/;
 }
 
-sub getRegexpOidMatch {
-    my ($match) = @_;
-
-    return $match unless $match && $match =~ /^[0-9.]+$/;
-
-    # Protect dots for regexp compilation
-    $match =~ s/\./\\./g;
-
-    return qr/^$match/;
-}
-
 1;
 __END__
 
@@ -176,7 +140,3 @@ return a clean integer value.
 =head2 isInteger($value)
 
 return true if value is an integer.
-
-=head2 getRegexpOidMatch($oid)
-
-return compiled regexp to match given oid.
