@@ -3,7 +3,7 @@ package FusionInventory::Agent::Tools::Screen::Philips;
 use strict;
 use warnings;
 
-use base 'FusionInventory::Agent::Tools::Screen';
+use parent 'FusionInventory::Agent::Tools::Screen';
 
 # Handles case monitor doesn't report serial2 in edid while it is connected
 # throught HDMI port. In that case, we uses serial1 as an integer, not hex.
