@@ -250,16 +250,6 @@ sub getRegistryValue {
         return _call_win32_ole_dependent_api($win32_ole_dependent_api);
     }
 
-    # Handle differently paths including /**/ pattern
-    if ($root =~ m/\/\*\*(?:\/.*|)$/ || $keyName eq '**') {
-        return _getRegistryDynamic(
-            logger    => $params{logger},
-            path      => "$root/$keyName",
-            valueName => $valueName,
-            withtype  => $params{withtype}
-        );
-    }
-
     my $key = _getRegistryKey(
         logger  => $params{logger},
         root    => $root,
@@ -270,7 +260,7 @@ sub getRegistryValue {
 
     if ($valueName eq '*') {
         my %ret;
-        foreach (grep { m|^/| } keys %$key) {
+        foreach (keys %$key) {
             s{^/}{};
             $ret{$_} = $params{withtype} ? [$key->GetValue($_)] : $key->{"/$_"} ;
         }
@@ -377,7 +367,7 @@ sub getRegistryKey {
     );
 }
 
-sub _getRegistryRoot {
+sub _getRegistryKey {
     my (%params) = @_;
 
     ## no critic (ProhibitBitwise)
@@ -391,72 +381,11 @@ sub _getRegistryRoot {
         ) if $params{logger};
         return;
     }
-    return $rootKey;
-}
-
-sub _getRegistryKey {
-    my (%params) = @_;
-
-    my $rootKey = _getRegistryRoot(%params)
-        or return;
-
     my $key = $rootKey->Open($params{keyName});
 
     return $key;
 }
 
-sub _getRegistryDynamic {
-    my (%params) = @_;
-
-    my %ret;
-    my $valueName = $params{valueName};
-
-    my @rootparts = split(/\/+\*\*\/+/, $params{path}.'/', 2);
-    my $first = shift(@rootparts);
-    my $second = shift(@rootparts) || '';
-    $first .= '/';
-    $second = '/'.$second;
-    $second =~ s|/*$||;
-
-    my $rootSub = _getRegistryRoot(
-        root    => $first,
-        logger  => $params{logger}
-    );
-    return unless defined($rootSub);
-
-    foreach my $sub ($rootSub->SubKeyNames) {
-        if ($second =~ m/\/+\*\*(?:\/.*|)/) {
-            my $subret = _getRegistryDynamic(
-                logger    => $params{logger},
-                path      => $first.$sub.$second,
-                valueName => $valueName,
-                withtype  => $params{withtype}
-            );
-            next unless defined($subret);
-            my ($subkey) = $second =~ /^([^*]+)\*\*(?:\/.*|)$/;
-            foreach my $subretkey (keys %$subret) {
-                $ret{$sub.$subkey.$subretkey} = $subret->{$subretkey};
-            }
-        } else {
-            my $key = _getRegistryRoot(
-                root    => $first.$sub.$second,
-                logger  => $params{logger}
-            );
-            next unless defined($key);
-
-            if ($valueName eq '*') {
-                foreach (grep { m|^/| } keys %$key) {
-                    s{^/}{};
-                    $ret{$sub.$second."/".$_} = $params{withtype} ? [$key->GetValue($_)] : $key->{"/$_"} ;
-                }
-            } elsif (exists($key->{"/$valueName"})) {
-                $ret{$sub.$second."/".$valueName} = $params{withtype} ? [$key->GetValue($valueName)] : $key->{"/$valueName"} ;
-            }
-        }
-    }
-    return \%ret;
-}
-
 sub _getRegistryKeyFromWMI{
     my (%params) = @_;
 
@@ -745,7 +674,7 @@ sub getInterfaces {
                 $interface->{DNSDomain} = $configuration->{DNSDomain}
                     if $configuration->{DNSDomain};
 
-                $interface->{SPEED}      = int($object->{Speed} / 1_000_000)
+                $interface->{SPEED}      = $object->{Speed} / 1_000_000
                     if $object->{Speed};
                 $interface->{VIRTUALDEV} = _isVirtual($object, $configuration);
 
@@ -769,7 +698,7 @@ sub getInterfaces {
             $interface->{DNSDomain} = $configuration->{DNSDomain}
                 if $configuration->{DNSDomain};
 
-            $interface->{SPEED}      = int($object->{Speed} / 1_000_000)
+            $interface->{SPEED}      = $object->{Speed} / 1_000_000
                 if $object->{Speed};
             $interface->{VIRTUALDEV} = _isVirtual($object, $configuration);
 
@@ -787,9 +716,6 @@ sub _isVirtual {
 
     # PhysicalAdapter only work on OS > XP
     if (defined $object->{PhysicalAdapter}) {
-        # Some virtual network adapters like VirtualBox or VPN ones could be set
-        # as physical but with PNPDeviceID starting by ROOT
-        return 1 if (defined($object->{PNPDeviceID}) && $object->{PNPDeviceID} =~ /^ROOT/);
         return $object->{PhysicalAdapter} ? 0 : 1;
     }
 
@@ -875,7 +801,7 @@ sub getAgentMemorySize {
     };
     return -1 unless (defined($ph));
 
-    my ($size, $pages) = ( -1, 0 );
+    my $size = -1;
     eval {
         # memory usage is bundled up in ProcessMemoryCounters structure
         # populated by GetProcessMemoryInfo() win32 call
@@ -910,24 +836,12 @@ sub getAgentMemorySize {
             )'
         );
         if ($apiGetProcessMemoryInfo->Call($ph, $mem_counters, $cb)) {
-            # Uses WorkingSetSize and PagefileUsage
+            # Uses WorkingSetSize as process memory size
             $size = $mem_counters->{WorkingSetSize};
-            $pages = $mem_counters->{PagefileUsage};
         }
     };
 
-    # Don't forget to close Process Handle
-    eval {
-        my $apiCloseHandle = Win32::API->new(
-            'kernel32',
-            'CloseHandle',
-            'I',
-            'I'
-        );
-        $ph = $apiCloseHandle->Call($ph);
-    };
-
-    return $size, $pages;
+    return $size;
 }
 
 sub FreeAgentMem {
@@ -967,10 +881,6 @@ my @win32_ole_calls : shared;
 sub start_Win32_OLE_Worker {
 
     unless (defined($worker)) {
-
-        # Handle thread KILL signal
-        $SIG{KILL} = sub { threads->exit(); };
-
         # Request a semaphore on which worker blocks immediatly
         Thread::Semaphore->require();
         $worker_semaphore = Thread::Semaphore->new(0);
@@ -978,8 +888,6 @@ sub start_Win32_OLE_Worker {
         # Start a worker thread
         $worker = threads->create( \&_win32_ole_worker );
     }
-
-    return $worker;
 }
 
 sub setupWorkerLogger {
